[PVFS2-CVS] commit by robl in pvfs2-1/src/common/misc: tcache.c

CVS commit program cvs at parl.clemson.edu
Fri Jan 13 16:50:15 EST 2006


Update of /projects/cvsroot/pvfs2-1/src/common/misc
In directory parlweb:/tmp/cvs-serv8917/src/common/misc

Modified Files:
	tcache.c 
Log Message:
[pcarns]: fix a memory leak if the acache is disabled


Index: tcache.c
===================================================================
RCS file: /projects/cvsroot/pvfs2-1/src/common/misc/tcache.c,v
diff -u -w -p -u -r1.2 -r1.3
--- tcache.c	21 Dec 2005 00:23:07 -0000	1.2
+++ tcache.c	13 Jan 2006 21:50:14 -0000	1.3
@@ -265,7 +265,8 @@ int PINT_tcache_insert_entry(
 
     if(tcache->enable == 0)
     {
-        /* cache has been disabled, do nothing */
+        /* cache has been disabled, do nothing except discard payload*/
+        tcache->free_payload(payload);
         return(0);
     }
 



More information about the PVFS2-CVS mailing list